get_outer_faces

Function get_outer_faces 

pub fn get_outer_faces(block: &Block) -> (Vec<Face>, Vec<(Face, Face)>)
Build the six outer faces for a block and identify internal matches.

Arguments

  • block - Target plot3d block.

Returns

Tuple containing the exterior faces and any internal matching face pairs.