FaceRecord

Struct FaceRecord 

pub struct FaceRecord {
    pub block_index: usize,
    pub imin: usize,
    pub jmin: usize,
    pub kmin: usize,
    pub imax: usize,
    pub jmax: usize,
    pub kmax: usize,
    pub id: Option<usize>,
}
Compact record describing a face on a particular block.

Fields

block_index: usizeimin: usizejmin: usizekmin: usizeimax: usizejmax: usizekmax: usizeid: Option<usize>

Implementations

Source

impl FaceRecord

pub fn from_face(face: &Face) -> Self

Construct a record from a Face instance.

pub fn scale_indices(&mut self, factor: usize)

Scale the index ranges by factor.

pub fn divide_indices(&mut self, divisor: usize)

Reduce the index ranges by divisor.

pub fn to_face(&self, blocks: &[Block]) -> Option<Face>

Reconstruct a Face from this record using the provided blocks.