Forward and backward differencing for structured grid edges.
Structs
- Block
Diff - Differencing data at a single node in a 3D block.
- Face
Diff - Differencing data at a single node on a 2D face.
Functions
- find_
edges - Compute forward and backward differences along each direction for a 3D block.
- find_
face_ edges - Compute forward and backward differences along each direction for a 2D face.
Type Aliases
- Diff
Pair - Backward and forward difference pair:
(backward, forward). Each is a displacement vector[dx, dy, dz].