pub fn find_bounding_faces(
blocks: &[Block],
outer_faces_records: &[FaceRecord],
direction: &str,
side: &str,
tol_rel: Float,
node_tol_xyz: Float,
) -> (Vec<FaceRecord>, Vec<FaceRecord>, Vec<Face>, Vec<Face>)Expand description
Identify outer faces on the extreme of the requested axis using BFS.
Arguments
blocks- All blocks in the system.outer_faces_records- Optional pre-computed outer faces in record form.direction- Axis name ("x","y", or"z").side- Requested side ("min","max", or"both").tol_rel- Relative tolerance for plane selection.node_tol_xyz- Node matching tolerance for BFS linking.
Returns
Tuple containing serialized faces and raw face objects for the lower and upper planes.